@@ -1,4 +1,4 @@
-/* -*- Mode: Java; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: JavaScript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* ***** BEGIN LICENSE BLOCK *****
  * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
@@ -20,6 +20,7 @@
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
+ *   Joachim Herb <herb@leo.org>
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,28 +36,28 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-//@line 39 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 40 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 
-//@line 45 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 46 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 
-pref("general.useragent.extra.thunderbird", "Thunderbird/3.0.11");
+pref("general.useragent.extra.thunderbird", "Thunderbird/3.1");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
 
-//@line 55 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 56 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 
 pref("mail.rights.version", 0);
 
 // Don't show the about:rights notification in debug or non-official builds.
-//@line 65 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 66 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 
 // gtk2 (*nix) lacks transparent/translucent drag support (bug 376238), so we
 // want to disable it so people can see where they are dragging things.
 // (Stock gtk drag icons will be used instead.)
-//@line 70 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 71 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 pref("nglayout.enable_drag_images", false);
-//@line 72 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 73 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 
 // App-specific update preferences
 
@@ -93,9 +94,6 @@ pref("app.update.url.details", "http://www.mozillamessaging.com/%LOCALE%/%APP%/r
 // User-settable override to app.update.url for testing purposes.
 //pref("app.update.url.override", "");
 
-// Interval: Time between checks for a new version (in seconds)
-//           default=1 day
-pref("app.update.interval", 86400);
 // Interval: Time before prompting the user again to restart to install the
 //           latest download (in seconds) default=1 day
 pref("app.update.nagTimer.restart", 86400);
@@ -141,7 +139,7 @@ pref("extensions.logging.enabled", false);
 //  .. etc ..
 //
 pref("extensions.update.enabled", true);
-pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&maxAppVersion=%ITEM_MAXAPPVERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&appOS=%APP_OS%&appABI=%APP_ABI%&locale=%APP_LOCALE%&currentAppVersion=%CURRENT_APP_VERSION%");
+pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&maxAppVersion=%ITEM_MAXAPPVERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&appOS=%APP_OS%&appABI=%APP_ABI%&locale=%APP_LOCALE%&currentAppVersion=%CURRENT_APP_VERSION%&updateType=%UPDATE_TYPE%");
 
 pref("extensions.update.interval", 86400);  // Check for updates to Extensions and 
                                             // Themes every day
@@ -165,6 +163,7 @@ pref("extensions.getAddons.search.browseURL", "https://%LOCALE%.add-ons.mozilla.
 pref("extensions.getAddons.search.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/search/%TERMS%/all/10/%OS%/%VERSION%");
 
 pref("xpinstall.whitelist.add", "update.mozilla.org");
+pref("xpinstall.whitelist.add.36", "getpersonas.com");
 pref("xpinstall.whitelist.add.103", "addons.mozilla.org");
 
 pref("mail.shell.checkDefaultClient", true);
@@ -182,11 +181,11 @@ pref("mail.last_msg_movecopy_target_uri", "");
 // last move or copy operation was a move
 pref("mail.last_msg_movecopy_was_move", true);
 
-//@line 200 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 199 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.instantApply", true);
-//@line 205 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 204 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 207 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 206 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 
 pref("browser.download.show_plugins_in_list", false);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -198,6 +197,13 @@ pref("accessibility.typeaheadfind.flashBar", 1);
 
 pref("mail.close_message_window.on_delete", false);
 
+// Number of lines of To/CC/BCC address headers to show before "more"
+// truncates the list.
+pref("mailnews.headers.show_n_lines_before_more", 1);
+
+// Thunderbird wants to show the migration assistant on upgrade by default.
+pref("mail.ui.show.migration.on.upgrade", true);
+
 /////////////////////////////////////////////////////////////////
 // Overrides of the core mailnews.js prefs
 /////////////////////////////////////////////////////////////////
@@ -217,9 +223,6 @@ pref("mailnews.headers.minNumHeaders", 0); // 0 means we ignore this pref
 // 3="<author> wrote On <date>:", 4=user specified
 pref("mailnews.reply_header_type", 2);
 
-// This turns off always showing a reply button in the message reader header
-pref("mailnews.headers.always_show_reply_sender", true);
-
 pref("mail.operate_on_msgs_in_collapsed_threads", true);
 pref("mail.warn_on_collapsed_thread_operation", true);
 
@@ -258,9 +261,9 @@ pref("offline.send.unsent_messages",            0);
 // 2 Never synchronize the offline store when going offline
 pref("offline.download.download_messages",  0);
 
-//@line 279 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 282 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 pref("offline.autoDetect", false);
-//@line 285 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 288 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 
 // Expose only select protocol handlers. All others should go
 // through the external protocol handler route.
@@ -413,27 +416,32 @@ pref("mail.tabs.closeButtons", 1);
 pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
 
 // OS Integrated Search and Indexing
-//@line 446 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 449 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 
 // -- Windows Search/Spotlight logging options
-//@line 461 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 464 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 
 // Whether to use a panel that looks like an OS X sheet for customization
-//@line 466 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 469 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 pref("toolbar.customization.usesheet", false);
-//@line 468 "/buildbot/linux_build_30/build/mail/app/profile/all-thunderbird.js"
+//@line 471 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 
 // Check for missing attachments?
 pref("mail.compose.attachment_reminder", true);
 // Words that should trigger a missing attachments warning.
 pref("mail.compose.attachment_reminder_keywords", "chrome://messenger/locale/messengercompose/composeMsgs.properties");
+// When no action is taken on the inline missing attachement notification,
+// show an alert on send?
+pref("mail.compose.attachment_reminder_aggressive", true);
 
 pref("browser.formfill.enable", true);
+//@line 482 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 // Override the all.js values so that unit tests pass and we get sane values.
 pref("browser.formfill.expire_days", 180);
 pref("browser.history_expire_days", 180);
 pref("browser.history_expire_days_min", 90);
 pref("browser.history_expire_sites", 40000);
+//@line 488 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 
 // Disable autoplay as we don't handle audio elements in emails very well.
 // See bug 515082.
@@ -450,6 +458,35 @@ pref("mailnews.database.global.logging.console", true);
 // page to load to find good header add-ons
 pref("mailnews.migration.header_addons_url","http://live.mozillamessaging.com/%APP%/addons/search?q=header&locale=%LOCALE%&lver=%VERSION%&hver=%VERSION%&os=%OS%");
 
+// Serif fonts look dated.  Switching those language families to sans-serif
+// where we think it makes sense.  Worth investigating for other font families
+// as well, viz bug 520824.  See all.js for the rest of the font families
+// preferences.
+pref("font.default", "sans-serif");
+pref("font.default.x-unicode", "sans-serif");
+pref("font.default.x-western", "sans-serif");
+
+//@line 527 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
+
+// Since different versions of Windows need different settings, we'll handle
+// this in mailMigrator.js.
+
+// Linux, in other words.  Other OSes may wish to override.
+//@line 533 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
+// The font.name-list fallback is defined in case font.name isn't
+// present -- e.g. in case a profile that's been used on Windows Vista or above
+// is used on Linux.
+pref("font.name-list.serif.x-unicode", "serif");
+pref("font.name-list.sans-serif.x-unicode", "sans-serif");
+pref("font.name-list.monospace.x-unicode", "monospace");
+
+pref("font.name-list.serif.x-western", "serif");
+pref("font.name-list.sans-serif.x-western", "sans-serif");
+pref("font.name-list.monospace.x-western", "monospace");
+//@line 544 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
+
+pref("mail.font.windows.version", 0);
+
 // What level of warning should we send to the error console?
 pref("mail.wizard.logging.console", "None");
 // What level of warning should we send to stdout via dump?
